@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 This module provides support for closures and inner functions.
 
@@ -48,6 +49,7 @@ outer, so all variables can be resolved.
 
 These scopes are instances of a numba extension class.
 """
+from __future__ import print_function, division, absolute_import
 
 import ast
 import ctypes
@@ -59,6 +61,7 @@ from numba import visitors
 from numba import nodes
 from numba import typesystem
 from numba import typedefs
+from numba import numbawrapper
 from numba import extension_types
 from numba import utils
 from numba.type_inference import module_type_inference
@@ -69,6 +72,15 @@ import logging
 logger = logging.getLogger(__name__)
 #logger.setLevel(logging.DEBUG)
 
+#------------------------------------------------------------------------
+# Utilities
+#------------------------------------------------------------------------
+
+def is_closure_signature(func_signature):
+    return (func_signature is not None and
+            func_signature.args and
+            func_signature.args[0].is_closure_scope)
+
 #------------------------------------------------------------------------
 # Closure Signature Validation (type inference of outer function)
 #------------------------------------------------------------------------
@@ -491,7 +503,7 @@ class ClosureSpecializer(ClosureTransformer):
         node.lfunc_pointer = translator.lfunc_pointer
 
         if node.need_numba_func:
-            return self.create_numba_function(node, translator)
+            return self.create_numba_function(node, node.func_env)
         else:
             func_name = node.func_def.name
             self.symtab[func_name] = Variable(name=func_name, type=node.type,
@@ -501,7 +513,9 @@ class ClosureSpecializer(ClosureTransformer):
             # return nodes.NoneNode()
             return nodes.ObjectInjectNode(None, type=object_)
 
-    def create_numba_function(self, node, translator):
+    def create_numba_function(self, node, func_env):
+        from numba.codegen import llvmwrapper
+
         closure_scope = self.ast.cur_scope
 
         if closure_scope is None:
@@ -511,8 +525,12 @@ class ClosureSpecializer(ClosureTransformer):
             assert node.func_def.args.args[0].variable.type
             scope_type = closure_scope.type
 
-        node.wrapper_func, node.wrapper_lfunc, methoddef = (
-                    translator.build_wrapper_function(get_lfunc=True))
+        self.env.translation.push_env(func_env)
+        try:
+            node.wrapper_func, node.wrapper_lfunc, methoddef = (
+                        llvmwrapper.build_wrapper_function(self.env))
+        finally:
+            self.env.translation.pop()
 
         # Keep methoddef alive
         # assert methoddef in node.py_func.live_objects
@@ -532,7 +550,7 @@ class ClosureSpecializer(ClosureTransformer):
 
         # Create function with closure scope at runtime
         create_numbafunc = nodes.ptrfromint(
-                        extension_types.NumbaFunction_NewEx_pointer,
+                        numbawrapper.NumbaFunction_NewEx_pointer,
                         create_numbafunc_signature.pointer())
 
         methoddef_p = ctypes.cast(ctypes.byref(methoddef),
@@ -580,6 +598,7 @@ class ClosureSpecializer(ClosureTransformer):
         Retrieve the closure scope from ((NumbaFunctionObject *)
                                              numba_func).func_closure
         """
+        # TODO: use llvmwrapper.get_closure_scope()
         pointer = nodes.ptrfromobj(node.func)
         type = typedefs.NumbaFunctionObject.ref()
         closure_obj_struct = nodes.CoercionNode(pointer, type)
