@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+from __future__ import print_function, division, absolute_import
 import weakref
 import ast as ast_module
 import types
@@ -6,7 +8,7 @@ import pprint
 
 import llvm.core
 
-from numba import pipeline, naming, error, reporting
+from numba import pipeline, naming, error, reporting, PY3
 from numba.control_flow.control_flow import ControlFlow
 from numba.utils import TypedProperty, WriteOnceTypedProperty, NumbaContext
 from numba.minivect.minitypes import FunctionType
@@ -14,6 +16,7 @@ from numba import functions, symtab
 from numba.utility.cbuilder import library
 from numba.nodes import metadata
 from numba.codegen import translate
+from numba.codegen import globalconstants
 
 from numba.intrinsic import default_intrinsic_library
 from numba.external import default_external_library
@@ -47,6 +50,7 @@ default_pipeline_order = [
     'Optimize',
     'Preloader',
     'SpecializeLoops',
+    'FixASTLocations',
     'LateSpecializer',
     'SpecializeFunccalls',
     'SpecializeExceptions',
@@ -71,12 +75,19 @@ default_dummy_type_infer_pipeline_order = [
     'TypeSet',
 ]
 
-default_numba_wrapper_pipeline_order = [
+default_numba_lower_pipeline_order = [
     'LateSpecializer',
     'SpecializeFunccalls',
     'SpecializeExceptions',
 ]
 
+
+default_numba_wrapper_pipeline_order = default_numba_lower_pipeline_order
+
+default_numba_late_translate_pipeline_order = \
+    default_numba_lower_pipeline_order + [
+    'CodeGen',
+]
 # ______________________________________________________________________
 # Convenience functions
 
@@ -290,13 +301,16 @@ class FunctionEnvironment(object):
         default=True,
     )
 
+    refcount_args = TypedProperty(
+        bool, "Whether to use refcounting for the function arguments", True)
+
     warn = TypedProperty(
         bool,
         'Flag that enables control flow warnings on a per-function level.',
         True)
 
     warnstyle = TypedProperty(
-        basestring,
+        str if PY3 else basestring,
         'Warning style, currently available: simple, fancy',
         default='fancy'
     )
@@ -320,6 +334,7 @@ class FunctionEnvironment(object):
              error_env=None, function_globals=None, locals=None,
              template_signature=None, cfg_transform=None,
              is_closure=False, closures=None, closure_scope=None,
+             refcount_args=True,
              ast_metadata=None, warn=True, warnstyle='fancy',
              **kws):
 
@@ -357,7 +372,7 @@ class FunctionEnvironment(object):
         if function_globals is not None:
             self.function_globals = function_globals
         else:
-            self.function_globals = self.func.func_globals
+            self.function_globals = self.func.__globals__
 
         self.locals = locals if locals is not None else {}
         self.template_signature = template_signature
@@ -366,6 +381,8 @@ class FunctionEnvironment(object):
         self.closures = closures if closures is not None else {}
         self.closure_scope = closure_scope
 
+        self.refcount_args = refcount_args
+
         if ast_metadata is not None:
             self.ast_metadata = ast_metadata
         else:
@@ -410,6 +427,13 @@ class FunctionEnvironment(object):
         state.update(kwds)
         return type(self)(**state)
 
+    @property
+    def func_doc(self):
+        if self.func is not None:
+            return self.func.__doc__
+        else:
+            return ast_module.get_docstring(self.ast)
+
 # ______________________________________________________________________
 
 class TranslationEnvironment(object):
@@ -672,6 +696,12 @@ class NumbaEnvironment(_AbstractNumbaEnvironment):
         "Manages the global LLVM module and linkages of new translations."
     )
 
+    constants_manager = TypedProperty(
+        globalconstants.LLVMConstantsManager,
+        "Holds constant values in an LLVM module.",
+        default=globalconstants.LLVMConstantsManager(),
+    )
+
     # ____________________________________________________________
     # Class members
 
@@ -698,6 +728,10 @@ class NumbaEnvironment(_AbstractNumbaEnvironment):
                 default_compile_pipeline_order),
             'wrap_func' : pipeline.ComposedPipelineStage(
                 default_numba_wrapper_pipeline_order),
+            'lower' : pipeline.ComposedPipelineStage(
+                default_numba_lower_pipeline_order),
+            'late_translate' : pipeline.ComposedPipelineStage(
+                default_numba_late_translate_pipeline_order),
             }
         self.context = NumbaContext()
         self.specializations = functions.FunctionCache(env=self)
@@ -741,6 +775,10 @@ class NumbaEnvironment(_AbstractNumbaEnvironment):
             cls.environment_map[environment_key] = ret_val
         return ret_val
 
+    @property
+    def crnt(self):
+        return self.translation.crnt
+
     def get_pipeline(self, pipeline_name=None):
         '''Convenience function for getting a pipeline object (which
         should be a callable object that accepts (ast, env) arguments,
