@@ -29,5 +29,5 @@ def convert_to_complex(x):
     return complex(x)
 
 if __name__ == '__main__':
-    import doctest
-    doctest.testmod()
+    import numba
+    numba.testmod()
