@@ -31,5 +31,5 @@ if __name__ == '__main__':
    # round2(10.497, 2)
    # round_val(object())
     round_val(3.6)
-    import doctest
-    doctest.testmod()
+    import numba
+    numba.testmod()
