@@ -2,14 +2,10 @@
 >>> error()
 Traceback (most recent call last):
     ...
-NumbaError: 17:4: object of type int cannot be sliced
+NumbaError: 13:4: object of type int cannot be sliced
 """
 
-import sys
-import ctypes
-
 from numba import *
-import numpy as np
 
 @autojit(backend='ast')
 def error():
@@ -17,5 +13,5 @@ def error():
     i[:]
 
 if __name__ == "__main__":
-    import doctest
-    doctest.testmod()
+    import numba
+    numba.testmod()
\ No newline at end of file
