@@ -32,5 +32,5 @@ def boom3():
     return object()('boom')
 
 if __name__ == "__main__":
-    import doctest
-    doctest.testmod()
+    import numba
+    numba.testmod()
