@@ -2,8 +2,7 @@ import sys
 import unittest
 import StringIO
 
-from numba.minivect import minitypes
-from numba import *
+from numba import autojit
 
 @autojit(backend='ast')
 def print_(value):
