@@ -1,3 +1,6 @@
+# -*- coding: utf-8 -*-
+from __future__ import print_function, division, absolute_import
+
 import os
 import sys
 import types
@@ -58,7 +61,7 @@ def skip_test(reason):
     if have_unit_skip:
         raise SkipTest(reason)
     else:
-        print >>sys.stderr, "Skipping: " + reason
+        print("Skipping: " + reason, file=sys.stderr)
 
 def skip_if(should_skip, message):
     def decorator(func):
@@ -107,8 +110,6 @@ class StdoutReplacer(object):
     def __exit__(self, *args):
         sys.stdout = self.out
 
-from .bytecode.test_support import ByteCodeTestCase
-
 def testmod(module=None, runit=False):
     """
     Tests a doctest modules with numba functions. When run in nosetests, only
