@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 This module provides a variety of transforms that transform the AST
 into a final form ready for code generation.
@@ -74,6 +75,7 @@ bytecode using meta. We run the following transformations:
         in the face of type coercions, which LLVM does not provide any
         leniency for.
 """
+from __future__ import print_function, division, absolute_import
 
 
 import sys
@@ -95,6 +97,7 @@ from numba.symtab import Variable
 from numba import visitors, nodes, error, functions
 from numba import stdio_util, function_util
 from numba.typesystem import is_obj, promote_closest, promote_to_native
+from numba.nodes import constnodes
 from numba.external import utility
 from numba.utils import dump
 
@@ -226,7 +229,7 @@ class ResolveCoercions(visitors.NumbaTransformer):
             logger.debug('coercion: %s --> %s\n%s',
                          node_type, dst_type, utils.pformat_ast(node))
 
-        if self.nopython and is_obj(node_type):
+        if self.nopython and (is_obj(node_type) ^ is_obj(dst_type)):
             raise error.NumbaError(node, "Cannot coerce to or from object in "
                                          "nopython context")
 
@@ -491,6 +494,7 @@ class LateSpecializer(ResolveCoercions, LateBuiltinResolverMixin,
         if self.nopython and is_obj(self.func_signature.return_type):
             error_return = nodes.WithPythonNode(body=[error_return])
 
+        error_return = self.visit(error_return)
         node.error_return = error_return
 
     def visit_ControlBlock(self, node):
@@ -797,7 +801,8 @@ class LateSpecializer(ResolveCoercions, LateBuiltinResolverMixin,
         # return nodes.ObjectTempNode(new_slice)
 
     def visit_Attribute(self, node):
-        if self.nopython and not node.value.type.is_module:
+        if (self.nopython and not node.value.type.is_module and
+            not node.value.type.is_complex):
             raise error.NumbaError(
                     node, "Cannot access Python attribute in nopython context (%s)" % node.attr)
 
@@ -936,7 +941,7 @@ class LateSpecializer(ResolveCoercions, LateBuiltinResolverMixin,
     def visit_Name(self, node):
         if node.variable.is_constant:
             obj = node.variable.constant_value
-            return nodes.const(obj, node.type)
+            return self.visit(nodes.const(obj, node.type))
 
         return node
 
@@ -1059,6 +1064,23 @@ class LateSpecializer(ResolveCoercions, LateBuiltinResolverMixin,
                     op_name)
         return node
 
+    def visit_ConstNode(self, node):
+        constant = node.pyval
+
+        if node.type.is_complex:
+            real = nodes.ConstNode(constant.real, node.type.base_type)
+            imag = nodes.ConstNode(constant.imag, node.type.base_type)
+            node = nodes.ComplexNode(real, imag)
+
+        elif node.type.is_pointer:
+            addr_int = constnodes.get_pointer_address(constant, node.type)
+            node = nodes.ptrfromint(addr_int, node.type)
+
+        elif node.type.is_object and not nodes.is_null_constant(constant):
+            node = nodes.ObjectInjectNode(constant, node.type)
+
+        return node
+
     #------------------------------------------------------------------------
     # User nodes
     #------------------------------------------------------------------------
