@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+from __future__ import print_function, division, absolute_import
 from .basetypes import *
 from .exttypes import *
 from .closuretypes import *
@@ -10,7 +12,7 @@ from .typeutils import *
 from .shorthands import *
 
 # from typeset import *
-from typematch import *
+from .typematch import *
 
 __all__ = minitypes.__all__ + [
     'O', 'b1', 'i1', 'i2', 'i4', 'i8', 'u1', 'u2', 'u4', 'u8',
