@@ -1,6 +1,8 @@
+# -*- coding: utf-8 -*-
 """
 Shorthands for type constructing, promotions, etc.
 """
+from __future__ import print_function, division, absolute_import
 
 from numba.typesystem import *
 from numba.minivect import minitypes
