@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+from __future__ import print_function, division, absolute_import
 import ast
 import ast as ast_module
 try:
@@ -140,13 +142,6 @@ class NumbaVisitorMixin(CooperativeBase):
             return self.kwargs["func_name"]
         return self.ast.name
 
-    @property
-    def func_doc(self):
-        if self.func is not None:
-            return self.func.__doc__
-        else:
-            return ast.get_docstring(self.ast)
-
     @property
     def qualified_name(self):
         qname = self.kwargs.get("qualified_name", None)
@@ -226,9 +221,8 @@ class NumbaVisitorMixin(CooperativeBase):
         self._overloads.setdefault(visit_name, []).append(func)
 
     def is_closure_signature(self, func_signature):
-        return (func_signature is not None and
-                func_signature.args and
-                func_signature.args[0].is_closure_scope)
+        from numba import closures
+        return closures.is_closure_signature(func_signature)
 
     def run_template(self, s, vars=None, **substitutions):
         from numba import templating
@@ -347,22 +341,22 @@ class NumbaTransformer(NumbaVisitorMixin, ast.NodeTransformer):
 
 class NoPythonContextMixin(object):
 
-    def visit_WithPythonNode(self, node):
-        if not self.nopython:
+    def visit_WithPythonNode(self, node, errorcheck=True):
+        if not self.nopython and errorcheck:
             raise error.NumbaError(node, "Not in 'with nopython' context")
 
         self.nopython -= 1
-        result = self.visitlist(node.body)
+        self.visitlist(node.body)
         self.nopython += 1
 
         return node
 
-    def visit_WithNoPythonNode(self, node):
-        if self.nopython:
+    def visit_WithNoPythonNode(self, node, errorcheck=True):
+        if self.nopython and errorcheck:
             raise error.NumbaError(node, "Not in 'with python' context")
 
         self.nopython += 1
-        result = self.visitlist(node.body)
+        self.visitlist(node.body)
         self.nopython -= 1
 
         return node
